@@ -3,7 +3,7 @@
 set -eu
 
 REPO=github.com/openshift/cluster-version-operator
-GOFLAGS=${GOFLAGS:-}
+GOFLAGS=${GOFLAGS:--mod=vendor}
 GLDFLAGS=${GLDFLAGS:-}
 
 eval $(go env | grep -e "GOHOSTOS" -e "GOHOSTARCH")
@@ -14,7 +14,8 @@ GOARCH=${GOACH:-${GOHOSTARCH}}
 # Go to the root of the repo
 cd "$(git rev-parse --show-cdup)"
 
-if [ -z ${VERSION_OVERRIDE+a} ]; then
+VERSION_OVERRIDE=${VERSION_OVERRIDE:-${OS_GIT_VERSION:-}}
+if [ -z "${VERSION_OVERRIDE:-}" ]; then
 	echo "Using version from git..."
 	VERSION_OVERRIDE=$(git describe --abbrev=8 --dirty --always)
 fi
@@ -30,4 +31,4 @@ fi
 mkdir -p ${BIN_PATH}
 
 echo "Building ${REPO} (${VERSION_OVERRIDE})"
-CGO_ENABLED=0 GOOS=${GOOS} GOARCH=${GOARCH} go build ${GOFLAGS} -ldflags "${GLDFLAGS}" -o ${BIN_PATH}/cluster-version-operator ${REPO}/cmd/...
+GOOS=${GOOS} GOARCH=${GOARCH} go build ${GOFLAGS} -ldflags "${GLDFLAGS}" -o ${BIN_PATH}/cluster-version-operator ${REPO}/cmd/...
